@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: David Zeuthen <davidz@redhat.com>
  */
@@ -513,7 +511,6 @@ update_account_object (GoaDaemon           *daemon,
   g_object_unref (account);
   g_free (type);
   g_free (identity);
-  g_free (presentation_identity);
   return ret;
 }
 
