@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: David Zeuthen <davidz@redhat.com>
  *          Debarshi Ray <debarshir@gnome.org>
@@ -45,7 +43,6 @@
 #include "goakerberosprovider.h"
 #endif
 
-#include "goaeditablelabel.h"
 #include "goautils.h"
 
 /**
