@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Ray Strode
  * Based on work by Colin Walters
@@ -143,8 +141,6 @@ goa_alarm_finalize (GObject *object)
 
   clear_scheduled_wakeups (self, self->priv->scheduled_wakeup_source, self->priv->stream);
 
-  g_rec_mutex_clear (&self->priv->lock);
-
   G_OBJECT_CLASS (goa_alarm_parent_class)->finalize (object);
 }
 
