@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Written by: Ray Strode
  *             Stef Walter
@@ -49,6 +47,9 @@ struct _GoaIdentityServicePrivate
 
   GoaIdentityManager       *identity_manager;
 
+  guint                     realmd_watch;
+  GCancellable             *cancellable;
+
   GHashTable               *watched_client_connections;
   GHashTable               *key_holders;
   GHashTable               *pending_temporary_account_results;
@@ -875,7 +876,7 @@ add_temporary_account (GoaIdentityService *self,
 {
   char               *realm;
   const char         *principal;
-  char               *principal_for_display;
+  const char         *principal_for_display;
   GSimpleAsyncResult *operation_result;
   GVariantBuilder     credentials;
   GVariantBuilder     details;
@@ -931,7 +932,6 @@ add_temporary_account (GoaIdentityService *self,
                                 on_account_added,
                                 operation_result);
   g_free (realm);
-  g_free (principal_for_display);
 }
 
 static void
@@ -1599,7 +1599,7 @@ on_identities_listed (GoaIdentityManager *manager,
           goa_warning ("Could not list identities: %s", error->message);
           g_error_free (error);
         }
-      goto out;
+      return;
     }
 
   for (node = identities; node != NULL; node = node->next)
@@ -1607,9 +1607,8 @@ on_identities_listed (GoaIdentityManager *manager,
       GoaIdentity *identity = node->data;
       const char  *principal;
       GoaObject   *object;
-      char        *object_path;
 
-      object_path = export_identity (self, identity);
+      export_identity (self, identity);
 
       principal = goa_identity_get_identifier (identity);
 
@@ -1619,12 +1618,7 @@ on_identities_listed (GoaIdentityManager *manager,
         add_temporary_account (self, identity);
       else
         g_object_unref (object);
-
-      g_free (object_path);
     }
-
- out:
-  g_object_unref (self);
 }
 
 static void
@@ -1687,7 +1681,7 @@ on_got_client (GoaClient          *client,
   if (self->priv->client == NULL)
     {
       goa_warning ("Could not create client: %s", error->message);
-      goto out;
+      return;
     }
 
   self->priv->accounts_manager = goa_client_get_manager (client);
@@ -1697,19 +1691,16 @@ on_got_client (GoaClient          *client,
   if (self->priv->identity_manager == NULL)
     {
       goa_warning ("Could not create identity manager: %s", error->message);
-      goto out;
+      return;
     }
 
   goa_identity_manager_list_identities (self->priv->identity_manager,
                                         NULL,
                                         (GAsyncReadyCallback)
                                         on_identities_listed,
-                                        g_object_ref (self));
+                                        self);
 
   ensure_credentials_for_accounts (self);
-
- out:
-  g_object_unref (self);
 }
 
 static void
@@ -1729,7 +1720,7 @@ on_session_bus_acquired (GDBusConnection    *connection,
     goa_client_new (NULL,
                     (GAsyncReadyCallback)
                     on_got_client,
-                    g_object_ref (self));
+                    self);
   }
 }
 
@@ -1761,6 +1752,8 @@ goa_identity_service_activate (GoaIdentityService   *self,
 
   goa_debug ("GoaIdentityService: Activating identity service");
 
+  self->priv->cancellable = g_cancellable_new ();
+
   self->priv->object_manager_server =
     g_dbus_object_manager_server_new ("/org/gnome/Identity");
 
@@ -1790,6 +1783,9 @@ goa_identity_service_deactivate (GoaIdentityService *self)
 {
   goa_debug ("GoaIdentityService: Deactivating identity service");
 
+  if (self->priv->realmd_watch == 0)
+    g_bus_unwatch_name (self->priv->realmd_watch);
+
   if (self->priv->identity_manager != NULL)
     {
       g_signal_handlers_disconnect_by_func (self, on_identity_needs_renewal, self);
@@ -1801,6 +1797,7 @@ goa_identity_service_deactivate (GoaIdentityService *self)
   g_clear_object (&self->priv->object_manager_server);
   g_clear_object (&self->priv->connection);
   g_clear_object (&self->priv->client);
+  g_clear_object (&self->priv->cancellable);
 }
 
 static void
