@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Ray Strode
  */
@@ -243,7 +241,7 @@ get_identifier (GoaKerberosIdentity  *self,
   krb5_principal principal;
   krb5_error_code error_code;
   char *unparsed_name;
-  char *identifier = NULL;
+  char *identifier;
 
   if (self->priv->credentials_cache == NULL)
     return NULL;
@@ -289,14 +287,12 @@ get_identifier (GoaKerberosIdentity  *self,
       goa_debug ("GoaKerberosIdentity: Error parsing principal identity name: %s",
                error_message);
       krb5_free_error_message (self->priv->kerberos_context, error_message);
-      goto out;
+      return NULL;
     }
 
   identifier = g_strdup (unparsed_name);
   krb5_free_unparsed_name (self->priv->kerberos_context, unparsed_name);
 
-out:
-  krb5_free_principal (self->priv->kerberos_context, principal);
   return identifier;
 }
 
@@ -334,7 +330,6 @@ set_error_from_krb5_error_code (GoaKerberosIdentity  *self,
   va_start (args, format);
   literal_message = g_strdup_vprintf (expanded_format, args);
   va_end (args);
-  g_free (expanded_format);
 
   g_set_error_literal (error, GOA_IDENTITY_ERROR, code, literal_message);
   g_free (literal_message);
@@ -638,8 +633,6 @@ verify_identity (GoaKerberosIdentity  *self,
             verification_level = VERIFICATION_LEVEL_EXISTS;
         }
 
-      krb5_free_cred_contents (self->priv->kerberos_context, &credentials);
-
       error_code = krb5_cc_next_cred (self->priv->kerberos_context,
                                       self->priv->credentials_cache,
                                       &cursor,
@@ -656,10 +649,9 @@ verify_identity (GoaKerberosIdentity  *self,
                                       error_code,
                                       _("Could not sift through identity "
                                         "credentials in cache: %k"));
-      goto end_sequence;
+      goto out;
     }
 
- end_sequence:
   error_code = krb5_cc_end_seq_get (self->priv->kerberos_context,
                                     self->priv->credentials_cache,
                                     &cursor);
@@ -793,6 +785,7 @@ set_alarm (GoaKerberosIdentity  *self,
 
       new_cancellable = g_cancellable_new ();
       goa_alarm_set_time (alarm, alarm_time, new_cancellable);
+      g_date_time_unref (alarm_time);
 
       g_clear_object (cancellable);
       *cancellable = new_cancellable;
@@ -865,7 +858,6 @@ reset_alarms (GoaKerberosIdentity *self)
   now = g_date_time_new_now_local ();
   expiration_time = g_date_time_new_from_unix_local (self->priv->expiration_time);
   time_span_until_expiration = g_date_time_difference (expiration_time, now);
-  g_date_time_unref (now);
 
   /* Let the user reauthenticate 10 min before expiration */
   expiring_time = g_date_time_add_minutes (expiration_time, -10);
@@ -888,9 +880,6 @@ reset_alarms (GoaKerberosIdentity *self)
              self->priv->expiration_alarm,
              expiration_time, &self->priv->expiration_alarm_cancellable);
 
-  g_date_time_unref (renewal_time);
-  g_date_time_unref (expiring_time);
-  g_date_time_unref (expiration_time);
   connect_alarm_signals (self);
 }
 
@@ -1397,7 +1386,8 @@ goa_kerberos_identity_renew (GoaKerberosIdentity *self, GError **error)
                                       _
                                       ("Could not get new credentials to renew identity %s: %k"),
                                       name);
-      goto free_principal;
+      krb5_free_principal (self->priv->kerberos_context, principal);
+      goto out;
     }
 
   if (!goa_kerberos_identity_update_credentials (self,
@@ -1405,15 +1395,12 @@ goa_kerberos_identity_renew (GoaKerberosIdentity *self, GError **error)
                                                  &new_credentials,
                                                  error))
     {
-      goto free_principal;
+      krb5_free_principal (self->priv->kerberos_context, principal);
+      goto out;
     }
 
   goa_debug ("GoaKerberosIdentity: identity %s renewed", name);
   renewed = TRUE;
-
-free_principal:
-  krb5_free_principal (self->priv->kerberos_context, principal);
-
 out:
   g_free (name);
 
