@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Ray Strode
  */
@@ -129,7 +127,7 @@ operation_new (GoaKerberosIdentityManager *self,
 {
   Operation *operation;
 
-  operation = g_slice_new0 (Operation);
+  operation = g_slice_new (Operation);
 
   operation->manager = self;
   operation->type = type;
@@ -794,7 +792,12 @@ get_new_credentials_cache (GoaKerberosIdentityManager *self,
   if (!supports_multiple_identities ||
       g_hash_table_size (self->priv->identities) == 0)
     {
-      error_code = krb5_cc_default (self->priv->kerberos_context, credentials_cache);
+      krb5_ccache default_cache;
+
+      error_code = krb5_cc_default (self->priv->kerberos_context, &default_cache);
+
+      if (error_code == 0)
+        krb5_cc_dup (self->priv->kerberos_context, default_cache, credentials_cache);
     }
   else
     {
@@ -842,18 +845,20 @@ sign_in_identity (GoaKerberosIdentityManager *self,
           g_simple_async_result_set_op_res_gpointer (operation->result, NULL, NULL);
           return;
         }
-
-      identity = goa_kerberos_identity_new (self->priv->kerberos_context,
-                                            credentials_cache,
-                                            &error);
-      krb5_cc_close (self->priv->kerberos_context, credentials_cache);
-      if (identity == NULL)
+      else
         {
-          g_simple_async_result_take_error (operation->result, error);
-          g_simple_async_result_set_op_res_gpointer (operation->result,
-                                                     NULL,
-                                                     NULL);
-          return;
+          identity = goa_kerberos_identity_new (self->priv->kerberos_context,
+                                                credentials_cache,
+                                                &error);
+          if (identity == NULL)
+            {
+              krb5_cc_close (self->priv->kerberos_context, credentials_cache);
+              g_simple_async_result_take_error (operation->result, error);
+              g_simple_async_result_set_op_res_gpointer (operation->result,
+                                                         NULL,
+                                                         NULL);
+              return;
+            }
         }
     }
   else
@@ -1460,8 +1465,6 @@ monitor_credentials_cache (GoaKerberosIdentityManager  *self,
   if (!can_monitor)
     self->priv->polling_timeout_id = g_timeout_add_seconds (FALLBACK_POLLING_INTERVAL, (GSourceFunc) on_polling_timeout, self);
 
-  krb5_cc_close (self->priv->kerberos_context, default_cache);
-
   return TRUE;
 }
 
@@ -1667,6 +1670,7 @@ goa_kerberos_identity_manager_new (GCancellable * cancellable, GError ** error)
                                  (gpointer *) &
                                  goa_kerberos_identity_manager_singleton);
 
+      error = NULL;
       if (!g_initable_init (G_INITABLE (object), cancellable, error))
         {
           g_object_unref (object);
